@@ -8,7 +8,7 @@ use warnings;
 package Mail::Toaster::Apache;
 
 use vars qw/ $VERSION /;
-$VERSION = '5.02';
+$VERSION = '5.05';
 
 use Carp;
 use English qw( -no_match_vars );
@@ -630,6 +630,7 @@ Alias /isoqlog/images/ "/usr/local/share/isoqlog/htmltemp/images/"
         print $MT_CONF '
 Alias /squirrelmail/ "/usr/local/www/squirrelmail/"
 <Directory "/usr/local/www/squirrelmail">
+    DirectoryIndex index.php
     Options Indexes ExecCGI
     AllowOverride None
     Order allow,deny
@@ -642,6 +643,7 @@ Alias /squirrelmail/ "/usr/local/www/squirrelmail/"
         print $MT_CONF '
 Alias /phpMyAdmin/ "/usr/local/www/phpMyAdmin/"
 <Directory "/usr/local/www/phpMyAdmin">
+    DirectoryIndex index.php
     Options Indexes ExecCGI
     AllowOverride None
     Order allow,deny
@@ -654,7 +656,6 @@ Alias /phpMyAdmin/ "/usr/local/www/phpMyAdmin/"
         print $MT_CONF '
 Alias /rrdutil/ "/usr/local/rrdutil/html/"
 <Directory "/usr/local/rrdutil/html">
-    Options Indexes ExecCGI
     AllowOverride None
     Order allow,deny
     Allow from all
@@ -666,7 +667,7 @@ Alias /rrdutil/ "/usr/local/rrdutil/html/"
         print $MT_CONF '
 Alias /roundcube "/usr/local/www/roundcube/"
 <Directory "/usr/local/www/roundcube">
-    Options Indexes FollowSymLinks
+    DirectoryIndex index.php
     AllowOverride All
     Order allow,deny
     Allow from all
@@ -676,6 +677,12 @@ Alias /roundcube "/usr/local/www/roundcube/"
 
     print $MT_CONF '
 Alias /v-webmail/ "/usr/local/www/v-webmail/htdocs/"
+<Directory "/usr/local/www/v-webmail">
+    DirectoryIndex index.php
+    AllowOverride All
+    Order allow,deny
+    Allow from all
+</Directory>
 ';
 
 #    if ($conf->{'install_apache'} == 22 ) {
